package market.Com.mapper;
import java.util.List;

import market.Com.vo.ComBaseSample;
import market.Slm.ContractManagement.vo.SlmContractLineInfo;

import org.apache.ibatis.annotations.Param;

import com.hnshituo.orm.GenericMapper;

public interface ComBaseSampleMapper extends GenericMapper<ComBaseSample,Object> {
	
	/**
	 * 查询流水号
	 * @return 返回一个三位流水号
	 */
	String doFindLs();
	
	String doFindL(@Param("phy_code_m")String phy_code_m);
	
	/**
	 * 恢复数据
	 */
	void doUpdatehuif(String smp_index);
	

	int syt(String id);
	
	
	List<ComBaseSample> GexList(String state,int pageindex,int pagesize,String steelname,String prodname,String std_name);
	
	int getcount(String state);
	List<ComBaseSample> findpop(@Param("param2") String param2);

	List<ComBaseSample> doSelectZlsj(String cic, String pRODUCT, String steel, String std, String tey);
	//获取com_base_sample取样码索引号
	List<ComBaseSample> getComBaseSample(SlmContractLineInfo scl);
	List<ComBaseSample> findBySample(String pic, String sample_key);
}
